@@ -191,7 +191,8 @@ class Getter:
         import zipfile
 
         z = zipfile.ZipFile(buffer)
-        body = z.open(z.namelist()[0]).read().decode("utf-8")
+        with z.open(z.namelist()[0]) as f:
+            body = f.read().decode("utf-8")
         return body
 
     def get_csv_from_s3(self, file_name):
@@ -213,13 +214,13 @@ class Getter:
         """
         Get parquet from S3
         """
-        # try:
-        import io
+        try:
+            import io
 
-        csv_obj = self.s3_client.get_object(Bucket="candas", Key=file_name)
-        df = pd.read_parquet(io.BytesIO(csv_obj["Body"].read()))
-        # except:
-        #    return None
+            csv_obj = self.s3_client.get_object(Bucket="candas", Key=file_name)
+            df = pd.read_parquet(io.BytesIO(csv_obj["Body"].read()))
+        except:
+            return None
         return df
 
     def get_pickle_from_s3(self, file_name):
@@ -245,17 +246,15 @@ class Getter:
 
         file_ticker = ticker.split(" ")[0]
 
-        dict_file = {"parquet": "get_parquet_from_s3", "pickle": "get_pickle_from_s3"}
+        dict_file = {
+            "parquet": "get_parquet_from_s3",
+            "pickle": "get_pickle_from_s3",
+            "csv": "get_csv_from_s3",
+        }
 
         path_name = f"DATA/{file_ticker}/{ticker}_{type}.{file_type}"
         df = getattr(self, dict_file[file_type])(path_name)
 
-        if df is None:
-
-            path_name = f"DATA/{file_ticker}/{ticker}_{type}.csv"
-            df = self.get_csv_from_s3(path_name)
-            df = df.loc[:, ~df.columns.str.contains("^Unnamed")]
-
         if df is None:
             if path.exists(f"{path_name}"):
                 df = pd.read_csv(f"{path_name}")
@@ -360,9 +359,9 @@ def save_guidance_csv(df, ticker, filename):
 
             df.columns = df.iloc[0]
             df = df.drop(df.index[0])
-            df.to_csv(pathname + "/" + ticker + "_guidance.csv")
-            print(ticker + " guidance done")
-            return df
+    df.to_csv(pathname + "/" + ticker + "_guidance.csv")
+    print(ticker + " guidance done")
+    return df
 
 
 def filter_dataset(
@@ -438,11 +437,6 @@ def filter_dataset(
                 .reset_index()
             )
 
-    df["period_name_sorted"] = (
-        df["period_name"].str.split("-").str[1]
-        + df["period_name"].str.split("-").str[0]
-    )
-
     if (
         type(time_series_name) is not list and time_series_name != ""
     ):  # this should be replaced with a search function
@@ -741,95 +735,6 @@ def get_forecast_url(csin, latest_version, mds_host=settings.MDS_HOST):
     )
 
 
-def dot_parse(
-    default_df, dot_file="", ticker="", auth_headers="", config=None, s3_client=None
-):
-    file_ticker = ticker.split(" ")[0]
-    if not config:
-        config = settings.CONFIG or resolve_config()
-    if not s3_client:
-        s3_client = Getter(config)
-
-    a_file = s3_client.get_file_from_s3(f"DATA/{file_ticker}/drivers.dot")
-
-    if a_file is None:
-        dot_file = create_drivers_dot("net-revenue", auth_headers, ticker)
-        a_file = open(dot_file)
-    else:
-        a_file = str(a_file).split("\\n")
-
-    keys = []
-    values = []
-
-    if type(a_file) == list:
-        a_file = iter(a_file)
-
-    next(a_file)
-
-    for line in a_file:
-        if "}" not in line:
-            if "->" in line:
-                key = line.split("->")[0]
-                key = key.replace("  ", "")
-                key = key.split("|")[0]
-                key = key.replace('"', "")
-                value = line.split("->")[1]
-                value = value.split("|")[0]
-                value = value.replace("\\n", "")
-                value = value.replace('"', "")
-                value = value.replace(" ", "")
-                value = value.replace("label=", "")
-                keys.append(key)
-                values.append(value)
-
-    data_tuples = list(zip(keys, values))
-    df = pd.DataFrame(data_tuples, columns=["dependent", "precedent"])
-    df = df.reset_index()
-
-    df1 = pd.merge(
-        df, default_df, how="inner", left_on="precedent", right_on="time_series_slug"
-    )[
-        ["index", "precedent", "time_series_name", "time_series_description"]
-    ].sort_values(
-        "index"
-    )
-    df2 = pd.merge(
-        df, default_df, how="inner", left_on="dependent", right_on="time_series_slug"
-    )[
-        ["index", "dependent", "time_series_name", "time_series_description"]
-    ].sort_values(
-        "index"
-    )
-    df = pd.merge(
-        df1, df2, how="inner", left_on="index", right_on="index"
-    )  # [['precedent','dependent','precedent_time_series_name','precedent_time_series_description','dependent_time_series_name','dependent_time_series_description']]
-    cols = []
-    for col in df.columns:
-        col = col.replace("_x", "_dependent")
-        col = col.replace("_y", "_precedent")
-        cols.append(col)
-    df.columns = cols
-    df = df[
-        [
-            "index",
-            "precedent",
-            "dependent",
-            "time_series_name_precedent",
-            "time_series_description_precedent",
-            "time_series_name_dependent",
-            "time_series_description_dependent",
-        ]
-    ]
-    df = df.groupby(["precedent", "dependent"]).first().reset_index()
-    df = df.sort_values("index")
-
-    return df
-
-
-def CompList(comp_name=""):
-    return COMP_LISTS.get(comp_name, "")
-
-
 def get_forecast_url_data(res_dict, ticker, auth_headers):
     list_out = []
     url = res_dict["self"]
@@ -1015,7 +920,8 @@ def create_drivers_dot(time_series, auth_headers, ticker, config=None, s3_client
             if not os.path.exists(f"{config.default_dir}/{path_name}"):
                 os.makedirs(f"{config.default_dir}/{path_name}")
             file_name = f"{config.default_dir}/{path_name}/drivers.dot"
-            open(file_name, "wb").write(dot_file)
+            with open(file_name, "wb") as f:
+                f.write(dot_file)
             return file_name
 
     if not os.path.exists(f"{config.default_dir}/{path_name}"):
@@ -1045,7 +951,8 @@ def create_drivers_dot(time_series, auth_headers, ticker, config=None, s3_client
 
         print(url)
         r = requests.get(url, headers=auth_headers, verify=False)
-        open(path_name, "wb").write(r.content)
+        with open(path_name, "wb") as f:
+            f.write(r.content)
         return path_name
 
 
@@ -1508,10 +1415,9 @@ def get_drivers_from_api(mds_host, csin, model_version, api_headers):
     Returns a list of drivers for the model with the specified CSIN and model version
     """
     driver_list = []
-    logger = LogFile(default_dir=settings.CONFIG.default_dir)
 
     forecast_period_name = get_forecast_period_name(
-        mds_host, csin, model_version, api_headers, logger
+        mds_host, csin, model_version, api_headers
     )
 
     driver_url = "api/equity-model-series/{csin}/equity-models/{model_version}/forecast-periods/{period}/data-points/?is_driver=true&page_size=200"
@@ -1519,13 +1425,13 @@ def get_drivers_from_api(mds_host, csin, model_version, api_headers):
     next_url: Optional[str] = driver_endpoint
 
     while next_url is not None:
-        drivers, next_url = _get_drivers_from_next_url(next_url, api_headers, logger)
+        drivers, next_url = _get_drivers_from_next_url(next_url, api_headers)
         driver_list.extend(drivers)
 
     return driver_list
 
 
-def get_forecast_period_name(mds_host, csin, model_version, api_headers, logger):
+def get_forecast_period_name(mds_host, csin, model_version, api_headers):
     """
     Retrieve the first forecast period name
     """
@@ -1536,7 +1442,7 @@ def get_forecast_period_name(mds_host, csin, model_version, api_headers, logger)
     try:
         response = requests.get(forecast_endpoint, headers=api_headers)
     except:
-        logger.write(f"Candas: Error with getting forecast period.")
+        print(f"Candas: Error with getting forecast period.")
         return
 
     forecast_period_name = response.json()["results"][0]["name"]
@@ -1544,14 +1450,14 @@ def get_forecast_period_name(mds_host, csin, model_version, api_headers, logger)
     return forecast_period_name
 
 
-def _get_drivers_from_next_url(url, api_headers, logger):
+def _get_drivers_from_next_url(url, api_headers):
     """
     Get drivers from specified url
     """
     try:
         response = requests.get(url, headers=api_headers)
     except:
-        logger.write(f"Candas: Error with getting drivers.")
+        print(f"Candas: Error with getting drivers.")
         return
 
     response_json = response.json()
@@ -1561,75 +1467,6 @@ def _get_drivers_from_next_url(url, api_headers, logger):
     return drivers, next_url
 
 
-COMP_LISTS = {}
-COMP_LISTS["Apparel"] = [
-    "FL US",
-    "BGFV US",
-    "BKE US",
-    "BURL US",
-    "MIK US",
-    "ULTA US",
-    "TSCO US",
-    "BOOT US",
-    "DXLG US",
-    "SCVL US",
-]
-COMP_LISTS["SAAS"] = [
-    "ASAN US",
-    "AYX US",
-    "AMSWA US",
-    "PLAN US",
-    "APPF US",
-    "TEAM US",
-    "ADSK US",
-    "AVLR US",
-    "BILL US",
-    "BLKB US",
-    "BL US",
-    "BOX US",
-    "NET US",
-    "COUP US",
-    "CRWD US",
-    "DDOG US",
-    "DOCU US",
-    "DOMO US",
-    "DBX US",
-    "DT US",
-    "ESTC US",
-    "HUBS US",
-    "JAMF US",
-    "FROG US",
-    "MDLA US",
-    "NCNO US",
-    "NEWR US",
-    "OKTA US",
-    "PD US",
-    "PAYC US",
-    "PCTY US",
-    "PING US",
-    "PS US",
-    "QTWO US",
-    "RNG US",
-    "CRM US",
-    "NOW US",
-    "SHOP CN",
-    "WORK US",
-    "SMAR US",
-    "SNOW US",
-    "SUMO US",
-    "TLND US",
-    "TENB US",
-    "TWLO US",
-    "VEEV US",
-    "WIX US",
-    "WDAY US",
-    "ZEN US",
-    "ZM US",
-    "ZI US",
-    "ZS US",
-]
-
-
 def get_chart_brand_config(
     chart_colors: List[str] = BRAND_CONFIG_DEFAULTS["chart_plot_colors"],
     figure_bg_color: str = BRAND_CONFIG_DEFAULTS["figure_bg_color"],
